# Create your views here.
from datetime import datetime
from datetime import timedelta

from django.contrib.auth.models import User
from django.shortcuts import render_to_response
from django.shortcuts import get_object_or_404
from django.http import HttpResponseRedirect

from website.models import Tweet, Profile
from website.forms import TweetForm

def index(request):
    if request.method == "POST":
        form = TweetForm(request.POST)
        if form.is_valid():
            cd = form.cleaned_data
            t = Tweet()
            t.user = request.user
            t.message = cd['message']
            t.save()
            return HttpResponseRedirect("/")
    else:
        form = TweetForm()
    tweets = Tweet.objects.all().order_by('-timestamp')
    return render_to_response("website/index.html",{'tweets': tweets, 'form': form})
    
    
    
    
    
    
def user_page(request, username):
    user = get_object_or_404(User, username=username)
    return render_to_response("website/user_page.html", {'profile':user.get_profile()})

def tweet_page(request, tweet_id):
    tweet = get_object_or_404(Tweet, id=tweet_id)
    return render_to_response("website/tweet_page.html", {'tweet':tweet})

def users_list(request):
    profiles = Profile.objects.filter(user__is_active=True)
    return render_to_response("website/users_page.html", {'profiles':profiles,'user':request.user})

def search(request):
    search = request.GET.get('s', '')
    tweets = Tweet.objects.filter(message__contains=search)
    return render_to_response("website/search.html",{'tweets':tweets, 'search':search})
    
def follow_user(request, username):
    user = get_object_or_404(User, username=username)
    profile = user.get_profile()
    my_profile = request.user.get_profile()
    
    if profile == my_profile: #Soy yo
        return render_to_response("website/error.html",{'message':"No puedes seguirte a ti mismo."})
    elif profile in my_profile.following.all(): #Ya le sigues
        return render_to_response("website/error.html",{'message':"Ya sigues a este usuario."})
    else: #Seguir
        profile.followers.add(my_profile)
        return HttpResponseRedirect("/users/")
    
def unfollow_user(request, username):
    user = get_object_or_404(User, username=username)
    profile = user.get_profile()
    my_profile = request.user.get_profile()
    
    if profile in my_profile.following.all(): #Ya le sigues
        profile.followers.remove(my_profile)
        return HttpResponseRedirect("/users/")
    else: #no le sigo
        return render_to_response("website/error.html",{'message':"No sigues a este usuario."})